summaryrefslogtreecommitdiff
path: root/include/basegfx
diff options
context:
space:
mode:
authorTor Lillqvist <tml@collabora.com>2017-09-22 14:12:07 +0300
committerTor Lillqvist <tml@collabora.com>2017-09-26 14:18:41 +0200
commit8e7897588d7185ef1964e8120669c1de3d1ce734 (patch)
tree8f48598670a5dc22703371943c05789d60b9a07d /include/basegfx
parent0b4135ec9945ea627318ecf5fccc4b7d0940ff0d (diff)
Rename the basegfx::tools namespace to basegfx::utils
Reduce potential confusion with the global tools namespace. Will hopefully make it possible to remove the annoying initial :: when referring to the global tools namespace. Unless we have even more tools subnamespaces somewhere. Thorsten said it was OK. Change-Id: Id088dfe8f4244cb79df9aa988995b31a1758c996 Reviewed-on: https://gerrit.libreoffice.org/42644 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Tor Lillqvist <tml@collabora.com>
Diffstat (limited to 'include/basegfx')
-rw-r--r--include/basegfx/color/bcolortools.hxx2
-rw-r--r--include/basegfx/matrix/b2dhommatrixtools.hxx12
-rw-r--r--include/basegfx/polygon/b2dlinegeometry.hxx4
-rw-r--r--include/basegfx/polygon/b2dpolygonclipper.hxx4
-rw-r--r--include/basegfx/polygon/b2dpolygoncutandtouch.hxx4
-rw-r--r--include/basegfx/polygon/b2dpolygontools.hxx4
-rw-r--r--include/basegfx/polygon/b2dpolypolygoncutter.hxx4
-rw-r--r--include/basegfx/polygon/b2dpolypolygontools.hxx4
-rw-r--r--include/basegfx/polygon/b2dtrapezoid.hxx4
-rw-r--r--include/basegfx/polygon/b3dpolygontools.hxx4
-rw-r--r--include/basegfx/polygon/b3dpolypolygontools.hxx4
-rw-r--r--include/basegfx/range/b2drangeclipper.hxx2
-rw-r--r--include/basegfx/utils/b2dclipstate.hxx (renamed from include/basegfx/tools/b2dclipstate.hxx)8
-rw-r--r--include/basegfx/utils/canvastools.hxx (renamed from include/basegfx/tools/canvastools.hxx)6
-rw-r--r--include/basegfx/utils/gradienttools.hxx (renamed from include/basegfx/tools/gradienttools.hxx)6
-rw-r--r--include/basegfx/utils/keystoplerp.hxx (renamed from include/basegfx/tools/keystoplerp.hxx)6
-rw-r--r--include/basegfx/utils/lerp.hxx (renamed from include/basegfx/tools/lerp.hxx)8
-rw-r--r--include/basegfx/utils/rectcliptools.hxx (renamed from include/basegfx/tools/rectcliptools.hxx)8
-rw-r--r--include/basegfx/utils/tools.hxx (renamed from include/basegfx/tools/tools.hxx)8
-rw-r--r--include/basegfx/utils/unopolypolygon.hxx (renamed from include/basegfx/tools/unopolypolygon.hxx)6
-rw-r--r--include/basegfx/utils/unotools.hxx (renamed from include/basegfx/tools/unotools.hxx)6
-rw-r--r--include/basegfx/utils/zoomtools.hxx (renamed from include/basegfx/tools/zoomtools.hxx)4
22 files changed, 59 insertions, 59 deletions
diff --git a/include/basegfx/color/bcolortools.hxx b/include/basegfx/color/bcolortools.hxx
index 64cdc95fd789..ad19d07c5125 100644
--- a/include/basegfx/color/bcolortools.hxx
+++ b/include/basegfx/color/bcolortools.hxx
@@ -28,7 +28,7 @@ namespace basegfx
{
class BColor;
- namespace tools
+ namespace utils
{
/// Transform from RGB to HSL
BASEGFX_DLLPUBLIC BColor rgb2hsl(const BColor& rRGBColor);
diff --git a/include/basegfx/range/b2drangeclipper.hxx b/include/basegfx/range/b2drangeclipper.hxx
index a196b210e6f1..3e37df1170f1 100644
--- a/include/basegfx/range/b2drangeclipper.hxx
+++ b/include/basegfx/range/b2drangeclipper.hxx
@@ -26,7 +26,7 @@
namespace basegfx
{
- namespace tools
+ namespace utils
{
/** Extract poly-polygon w/o self-intersections from poly-range
diff --git a/include/basegfx/tools/b2dclipstate.hxx b/include/basegfx/utils/b2dclipstate.hxx
index 865bdd74c765..5c3f615284ca 100644
--- a/include/basegfx/tools/b2dclipstate.hxx
+++ b/include/basegfx/utils/b2dclipstate.hxx
@@ -17,8 +17,8 @@
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_B2DCLIPSTATE_HXX
-#define INCLUDED_BASEGFX_TOOLS_B2DCLIPSTATE_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_B2DCLIPSTATE_HXX
+#define INCLUDED_BASEGFX_UTILS_B2DCLIPSTATE_HXX
#include <sal/types.h>
#include <o3tl/cow_wrapper.hxx>
@@ -33,7 +33,7 @@ namespace basegfx
class B2DPolyPolygon;
class B2DHomMatrix;
- namespace tools
+ namespace utils
{
class ImplB2DClipState;
@@ -93,6 +93,6 @@ namespace basegfx
}
}
-#endif // INCLUDED_BASEGFX_TOOLS_B2DCLIPSTATE_HXX
+#endif // INCLUDED_BASEGFX_UTILS_B2DCLIPSTATE_HXX
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/include/basegfx/tools/canvastools.hxx b/include/basegfx/utils/canvastools.hxx
index 9537b649f4d5..688dcd797df3 100644
--- a/include/basegfx/tools/canvastools.hxx
+++ b/include/basegfx/utils/canvastools.hxx
@@ -17,8 +17,8 @@
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_CANVASTOOLS_HXX
-#define INCLUDED_BASEGFX_TOOLS_CANVASTOOLS_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_CANVASTOOLS_HXX
+#define INCLUDED_BASEGFX_UTILS_CANVASTOOLS_HXX
#include <com/sun/star/uno/Reference.hxx>
#include <com/sun/star/uno/Sequence.hxx>
@@ -170,6 +170,6 @@ namespace basegfx
}
}
-#endif // INCLUDED_BASEGFX_TOOLS_CANVASTOOLS_HXX
+#endif // INCLUDED_BASEGFX_UTILS_CANVASTOOLS_HXX
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/include/basegfx/tools/gradienttools.hxx b/include/basegfx/utils/gradienttools.hxx
index ab73551143a8..6c754d4ed686 100644
--- a/include/basegfx/tools/gradienttools.hxx
+++ b/include/basegfx/utils/gradienttools.hxx
@@ -17,8 +17,8 @@
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_GRADIENTTOOLS_HXX
-#define INCLUDED_BASEGFX_TOOLS_GRADIENTTOOLS_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_GRADIENTTOOLS_HXX
+#define INCLUDED_BASEGFX_UTILS_GRADIENTTOOLS_HXX
#include <basegfx/point/b2dpoint.hxx>
#include <basegfx/range/b2drange.hxx>
@@ -120,7 +120,7 @@ namespace basegfx
}
};
- namespace tools
+ namespace utils
{
/** Create matrix for ODF's linear gradient definition
diff --git a/include/basegfx/tools/keystoplerp.hxx b/include/basegfx/utils/keystoplerp.hxx
index a0b5376f0174..57f0b0fe2579 100644
--- a/include/basegfx/tools/keystoplerp.hxx
+++ b/include/basegfx/utils/keystoplerp.hxx
@@ -17,8 +17,8 @@
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_KEYSTOPLERP_HXX
-#define INCLUDED_BASEGFX_TOOLS_KEYSTOPLERP_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_KEYSTOPLERP_HXX
+#define INCLUDED_BASEGFX_UTILS_KEYSTOPLERP_HXX
#include <basegfx/numeric/ftools.hxx>
#include <vector>
@@ -30,7 +30,7 @@ namespace com{ namespace sun{ namespace star{ namespace uno {
namespace basegfx
{
- namespace tools
+ namespace utils
{
/** Lerp in a vector of key stops
diff --git a/include/basegfx/tools/lerp.hxx b/include/basegfx/utils/lerp.hxx
index 6bb292569223..8dd3ca50435f 100644
--- a/include/basegfx/tools/lerp.hxx
+++ b/include/basegfx/utils/lerp.hxx
@@ -17,14 +17,14 @@
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_LERP_HXX
-#define INCLUDED_BASEGFX_TOOLS_LERP_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_LERP_HXX
+#define INCLUDED_BASEGFX_UTILS_LERP_HXX
#include <sal/types.h>
namespace basegfx
{
- namespace tools
+ namespace utils
{
/** Generic linear interpolator
@@ -46,6 +46,6 @@ namespace basegfx
}
}
-#endif // INCLUDED_BASEGFX_TOOLS_LERP_HXX
+#endif // INCLUDED_BASEGFX_UTILS_LERP_HXX
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/include/basegfx/tools/rectcliptools.hxx b/include/basegfx/utils/rectcliptools.hxx
index 9c4fd78b6b35..5ad90cb6ed81 100644
--- a/include/basegfx/tools/rectcliptools.hxx
+++ b/include/basegfx/utils/rectcliptools.hxx
@@ -17,8 +17,8 @@
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_RECTCLIPTOOLS_HXX
-#define INCLUDED_BASEGFX_TOOLS_RECTCLIPTOOLS_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_RECTCLIPTOOLS_HXX
+#define INCLUDED_BASEGFX_UTILS_RECTCLIPTOOLS_HXX
#include <sal/types.h>
#include <basegfx/range/b2ibox.hxx>
@@ -26,7 +26,7 @@
namespace basegfx
{
- namespace tools
+ namespace utils
{
namespace RectClipFlags
{
@@ -72,6 +72,6 @@ namespace basegfx
}
}
-#endif // INCLUDED_BASEGFX_TOOLS_RECTCLIPTOOLS_HXX
+#endif // INCLUDED_BASEGFX_UTILS_RECTCLIPTOOLS_HXX
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/include/basegfx/tools/tools.hxx b/include/basegfx/utils/tools.hxx
index 9aa52b01d9c2..b243d0167c81 100644
--- a/include/basegfx/tools/tools.hxx
+++ b/include/basegfx/utils/tools.hxx
@@ -17,8 +17,8 @@
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_TOOLS_HXX
-#define INCLUDED_BASEGFX_TOOLS_TOOLS_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_TOOLS_HXX
+#define INCLUDED_BASEGFX_UTILS_TOOLS_HXX
#include <sal/types.h>
#include <basegfx/basegfxdllapi.h>
@@ -29,7 +29,7 @@ namespace basegfx
class B2DRange;
class B2DPolyPolygon;
- namespace tools
+ namespace utils
{
/** Expand given parallelogram, such that it extends beyond
bound rect in a given direction.
@@ -122,6 +122,6 @@ namespace basegfx
}
}
-#endif // INCLUDED_BASEGFX_TOOLS_TOOLS_HXX
+#endif // INCLUDED_BASEGFX_UTILS_TOOLS_HXX
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/include/basegfx/tools/unopolypolygon.hxx b/include/basegfx/utils/unopolypolygon.hxx
index b59d126c6212..afe0fe9efeb8 100644
--- a/include/basegfx/tools/unopolypolygon.hxx
+++ b/include/basegfx/utils/unopolypolygon.hxx
@@ -17,8 +17,8 @@
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_UNOPOLYPOLYGON_HXX
-#define INCLUDED_BASEGFX_TOOLS_UNOPOLYPOLYGON_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_UNOPOLYPOLYGON_HXX
+#define INCLUDED_BASEGFX_UTILS_UNOPOLYPOLYGON_HXX
#include <cppuhelper/basemutex.hxx>
#include <cppuhelper/compbase.hxx>
@@ -106,6 +106,6 @@ namespace unotools
}
}
-#endif // INCLUDED_BASEGFX_TOOLS_UNOPOLYPOLYGON_HXX
+#endif // INCLUDED_BASEGFX_UTILS_UNOPOLYPOLYGON_HXX
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/include/basegfx/tools/unotools.hxx b/include/basegfx/utils/unotools.hxx
index fe9d18f191b2..3a58a2068fd9 100644
--- a/include/basegfx/tools/unotools.hxx
+++ b/include/basegfx/utils/unotools.hxx
@@ -7,8 +7,8 @@
* file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_UNOTOOLS_HXX
-#define INCLUDED_BASEGFX_TOOLS_UNOTOOLS_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_UNOTOOLS_HXX
+#define INCLUDED_BASEGFX_UTILS_UNOTOOLS_HXX
#include <cppuhelper/basemutex.hxx>
#include <com/sun/star/drawing/PolyPolygonBezierCoords.hpp>
@@ -33,6 +33,6 @@ namespace unotools
}
}
-#endif // INCLUDED_BASEGFX_TOOLS_UNOTOOLS_HXX
+#endif // INCLUDED_BASEGFX_UTILS_UNOTOOLS_HXX
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/include/basegfx/tools/zoomtools.hxx b/include/basegfx/utils/zoomtools.hxx
index 808da8f0ef57..533f25883e75 100644
--- a/include/basegfx/tools/zoomtools.hxx
+++ b/include/basegfx/utils/zoomtools.hxx
@@ -7,8 +7,8 @@
* file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
-#ifndef INCLUDED_BASEGFX_TOOLS_ZOOMTOOLS_HXX
-#define INCLUDED_BASEGFX_TOOLS_ZOOMTOOLS_HXX
+#ifndef INCLUDED_BASEGFX_UTILS_ZOOMTOOLS_HXX
+#define INCLUDED_BASEGFX_UTILS_ZOOMTOOLS_HXX
#include <sal/types.h>
#include <basegfx/basegfxdllapi.h>
diff --git a/include/basegfx/matrix/b2dhommatrixtools.hxx b/include/basegfx/matrix/b2dhommatrixtools.hxx
index aa3c047a20c5..c60a6ac96c21 100644
--- a/include/basegfx/matrix/b2dhommatrixtools.hxx
+++ b/include/basegfx/matrix/b2dhommatrixtools.hxx
@@ -29,7 +29,7 @@
namespace basegfx
{
- namespace tools
+ namespace utils
{
/** If the rotation angle is an approximate multiple of pi/2,
force fSin/fCos to -1/0/1, to maintain orthogonality (which
@@ -140,13 +140,13 @@ namespace basegfx
/// get column vector from B2dHomMatrix, e.g. to extract coordinate system origin and x/yaxis
BASEGFX_DLLPUBLIC B2DTuple getColumn(const B2DHomMatrix& rMatrix, sal_uInt16 nCol);
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
namespace basegfx
{
- namespace tools
+ namespace utils
{
class BASEGFX_DLLPUBLIC B2DHomMatrixBufferedDecompose
{
@@ -178,13 +178,13 @@ namespace basegfx
double getRotate() const { return mfRotate; }
double getShearX() const { return mfShearX; }
};
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
namespace basegfx
{
- namespace tools
+ namespace utils
{
class BASEGFX_DLLPUBLIC B2DHomMatrixBufferedOnDemandDecompose
{
@@ -223,7 +223,7 @@ namespace basegfx
const B2DVector& getTranslate() const { const_cast< B2DHomMatrixBufferedOnDemandDecompose* >(this)->impCheckDecompose(); return maTranslate; }
double getRotate() const { const_cast< B2DHomMatrixBufferedOnDemandDecompose* >(this)->impCheckDecompose(); return mfRotate; }
};
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
diff --git a/include/basegfx/polygon/b2dlinegeometry.hxx b/include/basegfx/polygon/b2dlinegeometry.hxx
index 60230cc9168c..8a9cef193cd3 100644
--- a/include/basegfx/polygon/b2dlinegeometry.hxx
+++ b/include/basegfx/polygon/b2dlinegeometry.hxx
@@ -30,7 +30,7 @@
namespace basegfx
{
- namespace tools
+ namespace utils
{
/** Create line start/end geometry element, mostly arrows and things like that.
@@ -138,7 +138,7 @@ namespace basegfx
double fMaxPartOfEdge = 0.4,
double fMiterMinimumAngle = (15.0 * F_PI180));
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
#endif // INCLUDED_BASEGFX_POLYGON_B2DLINEGEOMETRY_HXX
diff --git a/include/basegfx/polygon/b2dpolygonclipper.hxx b/include/basegfx/polygon/b2dpolygonclipper.hxx
index f50ac9e8f7f6..472cbf387b98 100644
--- a/include/basegfx/polygon/b2dpolygonclipper.hxx
+++ b/include/basegfx/polygon/b2dpolygonclipper.hxx
@@ -30,7 +30,7 @@ namespace basegfx
// predefinitions
class B2DRange;
- namespace tools
+ namespace utils
{
// This method clips the given tools::PolyPolygon against a horizontal or vertical axis (parallel to X or Y axis). The axis is
// defined by bParallelToXAxis (true -> it's parallel to the X-Axis of the coordinate system, else to the Y-Axis) and the
@@ -61,7 +61,7 @@ namespace basegfx
// to be a simple triangle list. the result is also a simple triangle list.
BASEGFX_DLLPUBLIC B2DPolygon clipTriangleListOnRange( const B2DPolygon& rCandidate, const B2DRange& rRange );
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
#endif // INCLUDED_BASEGFX_POLYGON_B2DPOLYGONCLIPPER_HXX
diff --git a/include/basegfx/polygon/b2dpolygoncutandtouch.hxx b/include/basegfx/polygon/b2dpolygoncutandtouch.hxx
index 0918e0e1d90d..61a5c5a7a7da 100644
--- a/include/basegfx/polygon/b2dpolygoncutandtouch.hxx
+++ b/include/basegfx/polygon/b2dpolygoncutandtouch.hxx
@@ -27,7 +27,7 @@
namespace basegfx
{
- namespace tools
+ namespace utils
{
// look for self-intersections and self-touches (points on an edge) in given polygon and add
// extra points there. Result will have no touches or intersections on an edge, only on points
@@ -47,7 +47,7 @@ namespace basegfx
// The mask polygon is assumed to be closed, even when it's not explicitly.
BASEGFX_DLLPUBLIC B2DPolygon addPointsAtCuts(const B2DPolygon& rCandidate, const B2DPolyPolygon& rMask);
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
diff --git a/include/basegfx/polygon/b2dpolygontools.hxx b/include/basegfx/polygon/b2dpolygontools.hxx
index b96834fc96f6..c20668995d56 100644
--- a/include/basegfx/polygon/b2dpolygontools.hxx
+++ b/include/basegfx/polygon/b2dpolygontools.hxx
@@ -55,7 +55,7 @@ namespace basegfx
class B2DPolygon;
class B2DRange;
- namespace tools
+ namespace utils
{
// B2DPolygon tools
@@ -498,7 +498,7 @@ namespace basegfx
*/
BASEGFX_DLLPUBLIC OUString exportToSvgPoints( const B2DPolygon& rPoly );
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
#endif // INCLUDED_BASEGFX_POLYGON_B2DPOLYGONTOOLS_HXX
diff --git a/include/basegfx/polygon/b2dpolypolygoncutter.hxx b/include/basegfx/polygon/b2dpolypolygoncutter.hxx
index b8bf5847dcc4..a84dca8e9ee8 100644
--- a/include/basegfx/polygon/b2dpolypolygoncutter.hxx
+++ b/include/basegfx/polygon/b2dpolypolygoncutter.hxx
@@ -26,7 +26,7 @@
namespace basegfx
{
- namespace tools
+ namespace utils
{
/** Solve all crossovers (aka self-intersections) in a polyPolygon.
@@ -141,7 +141,7 @@ namespace basegfx
*/
BASEGFX_DLLPUBLIC B2DPolyPolygon mergeToSinglePolyPolygon(const B2DPolyPolygonVector& rInput);
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
diff --git a/include/basegfx/polygon/b2dpolypolygontools.hxx b/include/basegfx/polygon/b2dpolypolygontools.hxx
index 90ec04530c52..3f34f8e6f7c5 100644
--- a/include/basegfx/polygon/b2dpolypolygontools.hxx
+++ b/include/basegfx/polygon/b2dpolypolygontools.hxx
@@ -37,7 +37,7 @@ namespace basegfx
class B2DPolyPolygon;
class B2DRange;
- namespace tools
+ namespace utils
{
// B2DPolyPolygon tools
@@ -291,7 +291,7 @@ namespace basegfx
const B2DPolyPolygon& rPolyPolygon,
css::drawing::PolyPolygonBezierCoords& rPolyPolygonBezierCoordsRetval);
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
#endif // INCLUDED_BASEGFX_POLYGON_B2DPOLYPOLYGONTOOLS_HXX
diff --git a/include/basegfx/polygon/b2dtrapezoid.hxx b/include/basegfx/polygon/b2dtrapezoid.hxx
index d50772874709..a4d8e1d77733 100644
--- a/include/basegfx/polygon/b2dtrapezoid.hxx
+++ b/include/basegfx/polygon/b2dtrapezoid.hxx
@@ -75,7 +75,7 @@ namespace basegfx
namespace basegfx
{
- namespace tools
+ namespace utils
{
// convert SourcePolyPolygon to trapezoids. The trapezoids will be appended to
// ro_Result. ro_Result will not be cleared. If SourcePolyPolygon contains curves,
@@ -104,7 +104,7 @@ namespace basegfx
const B2DPolygon& rPolygon,
double fLineWidth);
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
diff --git a/include/basegfx/polygon/b3dpolygontools.hxx b/include/basegfx/polygon/b3dpolygontools.hxx
index fa1442f19def..a38ece65f99c 100644
--- a/include/basegfx/polygon/b3dpolygontools.hxx
+++ b/include/basegfx/polygon/b3dpolygontools.hxx
@@ -34,7 +34,7 @@ namespace basegfx
class B3DPolygon;
class B3DRange;
- namespace tools
+ namespace utils
{
// B3DPolygon tools
@@ -120,7 +120,7 @@ namespace basegfx
*/
BASEGFX_DLLPUBLIC B3DPolygon snapPointsOfHorizontalOrVerticalEdges(const B3DPolygon& rCandidate);
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
#endif // INCLUDED_BASEGFX_POLYGON_B3DPOLYGONTOOLS_HXX
diff --git a/include/basegfx/polygon/b3dpolypolygontools.hxx b/include/basegfx/polygon/b3dpolypolygontools.hxx
index 142058362193..72177230c1e7 100644
--- a/include/basegfx/polygon/b3dpolypolygontools.hxx
+++ b/include/basegfx/polygon/b3dpolypolygontools.hxx
@@ -35,7 +35,7 @@ namespace basegfx
class B3DPolyPolygon;
class B3DRange;
- namespace tools
+ namespace utils
{
// B3DPolyPolygon tools
@@ -133,7 +133,7 @@ namespace basegfx
const B3DPolyPolygon& rPolyPolygonSource,
css::drawing::PolyPolygonShape3D& rPolyPolygonShape3DRetval);
- } // end of namespace tools
+ } // end of namespace utils
} // end of namespace basegfx
#endif // INCLUDED_BASEGFX_POLYGON_B3DPOLYPOLYGONTOOLS_HXX